package com.ekexiu.console.system.service;

import com.ekexiu.console.system.dao.ProfessorDao;
import com.ekexiu.console.system.dao.ResResultKeyWordDao;
import com.ekexiu.console.system.dao.ResearchResultDao;
import com.ekexiu.console.system.dao.ResearcherDao;
import com.ekexiu.console.system.po.ResearchResult;
import com.ekexiu.console.system.po.Researcher;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.DefaultValue;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.apt.web.annotation.param.PathVar;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;

/**
 * Created by TT on 2017/10/19.
 */
@Path("/resResult")
public class ResearchResultService {
    @Autowrie
    private ResearcherDao researcherDao;
    @Autowrie
    private ResearchResultDao researchResultDao;
    @Autowrie
    private ResResultKeyWordDao resResultKeyWordDao;
    @Autowrie
    private ProfessorDao professorDao;
    @Autowrie
    private KeyWordService keyWordService;

    public ResearcherDao getResearcherDao() {
        return researcherDao;
    }

    public void setResearcherDao(ResearcherDao researcherDao) {
        this.researcherDao = researcherDao;
    }

    public ResearchResultDao getResearchResultDao() {
        return researchResultDao;
    }

    public void setResearchResultDao(ResearchResultDao researchResultDao) {
        this.researchResultDao = researchResultDao;
    }

    public ResResultKeyWordDao getResResultKeyWordDao() {
        return resResultKeyWordDao;
    }

    public void setResResultKeyWordDao(ResResultKeyWordDao resResultKeyWordDao) {
        this.resResultKeyWordDao = resResultKeyWordDao;
    }

    public ProfessorDao getProfessorDao() {
        return professorDao;
    }

    public void setProfessorDao(ProfessorDao professorDao) {
        this.professorDao = professorDao;
    }

    public KeyWordService getKeyWordService() {
        return keyWordService;
    }

    public void setKeyWordService(KeyWordService keyWordService) {
        this.keyWordService = keyWordService;
    }

    @Path
    @Post
    public void insert(@JdbcConn(true)Connection con, ResearchResult researchResult, @Nullable String[] researchers)throws SQLException{
        String id = StringUtil.buildUUID();
        researchResult.setId(id);
        researchResult.setStatus("1");
        refreshSearchers(con,id,researchers);
        String subject = researchResult.getSubject();
        if (subject == null) {
            subject = "";
        }
        String industry = researchResult.getIndustry();
        if (industry == null)
            industry = "";
        this.keyWordService.refreshResearchResult(con,id,subject+","+industry);
        this.researchResultDao.insert(con, researchResult);
    }

    @Post
    @Path("/update")
    public void update(@JdbcConn(true)Connection con,ResearchResult researchResult,@Nullable String[] researchers)throws SQLException {
        this.researchResultDao.update(con, researchResult);
        ResearchResult result = this.researchResultDao.query(con, researchResult.getId());
        refreshSearchers(con, result.getId(), researchers);
        String subject = result.getSubject();
        if (subject == null) {
            subject = "";
        }
        String industry = result.getIndustry();
        if (industry == null)
            industry = "";
        this.keyWordService.refreshResearchResult(con,result.getId(),subject+","+industry);
    }

    @Get
    @Path("/pq")
    public PageQueryResult<ResearchResult> pageQuery(@JdbcConn Connection con,@Nullable String key,@Nullable String name,@Nullable String orgName,@Nullable String department,@Nullable String subject,@Nullable String industry, @Nullable String bt, @Nullable String et,@DefaultValue("10") int pageSize,
                                                     @DefaultValue("1") int pageNo)throws SQLException{
        if (key != null) {
            key = "%" + key + "%";
        }
        if (name != null) {
            name = "%" + name + "%";
        }
        if (orgName != null) {
            orgName = "%" + orgName + "%";
        }
        if (department != null) {
            department = "%" + department + "%";
        }
        if (subject != null) {
            subject = "%" + subject + "%";
        }
        if (industry != null) {
            industry = "%" + industry + "%";
        }
        return this.researchResultDao.pageQuery(con, key, name, orgName, department, subject, industry, bt == null ? null : bt + "000000", et == null ? null : et + "235959", pageSize, pageNo);
    }

    @Get
    @Path("/queryResearcher")
    public List<Researcher> queryResearchers(@JdbcConn Connection con, String id)throws SQLException {
        return this.researcherDao.query(con, id);
    }

    @Get
    @Path("/id/{id}")
    public ResearchResult query(@JdbcConn Connection con, @PathVar String id)throws SQLException {
        return this.researchResultDao.query(con, id);
    }

    @Post
    @Path("/delete")
    public void delete(@JdbcConn(true)Connection con, String id )throws SQLException{
        this.researchResultDao.updateStatus(con, id,"0");
    }


    public void refreshSearchers(Connection con, String id, String[] researchers)throws SQLException {
        this.researcherDao.delete(con, id);
        if (researchers != null && researchers.length > 0) {
            Researcher[] res = new Researcher[researchers.length];
            for (int i = 0;i<researchers.length;++i) {
                Researcher re = new Researcher();

                re.setId(id);
                re.setProfessorId(researchers[i].substring(0,32));
                re.setName(researchers[i].substring(33));
                res[i] = re;
            }
            this.researcherDao.insert(con, res);
        }
    }
}
