-- ----------------------------
-- Table structure for user_info
-- ----------------------------
CREATE TABLE public.user_info (
  id CHARACTER(32) PRIMARY KEY NOT NULL,
  org_name TEXT, -- 机构名称
  state TEXT NOT NULL, -- 审核状态(1-未提交，2-待审核，3-审核通过，4-审核失败)
  name TEXT NOT NULL, -- 姓名
  create_time TEXT NOT NULL, -- 创建时间
  cnt TEXT NOT NULL, -- 详细信息
  creator CHARACTER(32) NOT NULL, -- 创建人ID
  creator_name TEXT, -- 创建人姓名
  mobile TEXT, -- 注册手机
  email TEXT -- 注册邮箱
);
COMMENT ON COLUMN public.user_info.org_name IS '机构名称';
COMMENT ON COLUMN public.user_info.state IS '审核状态(1-未提交，2-待审核，3-审核通过，4-审核失败)';
COMMENT ON COLUMN public.user_info.name IS '姓名';
COMMENT ON COLUMN public.user_info.create_time IS '创建时间';
COMMENT ON COLUMN public.user_info.cnt IS '详细信息';
COMMENT ON COLUMN public.user_info.creator IS '创建人ID';
COMMENT ON COLUMN public.user_info.creator_name IS '创建人姓名';
COMMENT ON COLUMN public.user_info.mobile IS '注册手机';
COMMENT ON COLUMN public.user_info.email IS '注册邮箱';

-- ----------------------------
-- Uniques structure for table user_info
-- ----------------------------
ALTER TABLE USER_INFO ADD PRIMARY KEY (ID);

-----begin version 1.9------------------------
-- ----------------------------
-- Table structure for org_record
-- ----------------------------
CREATE TABLE public.org_record (
  id CHARACTER(32) PRIMARY KEY NOT NULL,
  creator CHARACTER(32), -- 创建人ID
  modifier CHARACTER(32), -- 修改人
  create_time CHARACTER(14), -- 创建时间
  modify_time CHARACTER(14) -- 修改时间
);
COMMENT ON COLUMN public.org_record.creator IS '创建人ID';
COMMENT ON COLUMN public.org_record.modifier IS '修改人ID';
COMMENT ON COLUMN public.org_record.create_time IS '创建时间';
COMMENT ON COLUMN public.org_record.modify_time IS '修改时间';



ALTER TABLE feedback ADD COLUMN operator  CHAR(32);
COMMENT ON COLUMN feedback.operator IS '处理人ID';
ALTER TABLE feedback ADD COLUMN operate_time  TEXT;
COMMENT ON COLUMN feedback.operate_time IS '处理时间';
ALTER TABLE feedback ADD COLUMN operate_descp TEXT;
COMMENT ON COLUMN feedback.operate_descp IS '处理备注';

-----begin version 1.9.1------------------------

ALTER TABLE article ADD COLUMN sort_num  int8 default 0 not null;
COMMENT ON COLUMN article.sort_num IS '排序字段，人工权重';

ALTER TABLE resource ADD COLUMN sort_num  int8 default 0 not null;
COMMENT ON COLUMN resource.sort_num IS '排序字段，人工权重';

-----begin version 1.9.2------------------------

-- ------------------------------------
-- Table structure for discover_banner
-- ------------------------------------
CREATE TABLE discover_banner (
  id bigserial PRIMARY KEY NOT NULL, -- 编号id
  title CHARACTER VARYING(50) NOT NULL, -- 外显标题
  banner SMALLINT NOT NULL, -- 栏目
  begin_time CHARACTER(14), -- 上架时间
  end_time CHARACTER(14), -- 下架时间
  clicks BIGINT NOT NULL DEFAULT 0, -- 点击量
  descp TEXT, -- 备注
  article_id CHARACTER(32) NOT NULL, -- 文章ID
  modify_time CHARACTER(14) NOT NULL, -- 修改时间
  modifier CHARACTER VARYING(32), -- 最后修改人ID
  create_time CHARACTER(14) NOT NULL, -- 创建时间
  creator CHARACTER VARYING(32) NOT NULL -- 创建人ID
);
COMMENT ON COLUMN discover_banner.id IS '编号id';
COMMENT ON COLUMN discover_banner.title IS '外显标题';
COMMENT ON COLUMN discover_banner.banner IS '栏目';
COMMENT ON COLUMN discover_banner.begin_time IS '上架时间';
COMMENT ON COLUMN discover_banner.end_time IS '下架时间';
COMMENT ON COLUMN discover_banner.clicks IS '点击量';
COMMENT ON COLUMN discover_banner.descp IS '备注';
COMMENT ON COLUMN discover_banner.article_id IS '文章ID';
COMMENT ON COLUMN discover_banner.modify_time IS '修改时间';
COMMENT ON COLUMN discover_banner.modifier IS '最后修改人ID';
COMMENT ON COLUMN discover_banner.create_time IS '创建时间';
COMMENT ON COLUMN discover_banner.creator IS '创建人ID';


-----begin version 2.1.0------------------------

-- ------------------------------------
-- Table structure for research_result
-- ------------------------------------
CREATE TABLE public.research_result (
  id CHARACTER(32) PRIMARY KEY NOT NULL,
  name TEXT NOT NULL, -- 成果名称
  level TEXT, -- 技术水平
  org_name TEXT, -- 所属机构
  department TEXT, -- 所属部门
  subject TEXT, -- 行业领域
  industry TEXT, -- 应用领域
  descp TEXT, -- 成果简介
  apply_descp TEXT, -- 应用介绍
  prospect TEXT, -- 产业化前景
  indicator TEXT, -- 技术指标
  advantage TEXT, -- 技术优势
  benefit TEXT, -- 经济和社会效益
  cooperation TEXT, -- 合作备注
  linkman TEXT, -- 联系人
  addr TEXT, -- 地址
  zip_code TEXT, -- 邮编
  tel TEXT, -- 办公电话
  mobile TEXT, -- 手机
  email TEXT, -- 邮箱
  pic TEXT, -- 图片
  create_time CHARACTER(14) NOT NULL, -- 创建时间
  modify_time CHARACTER(14) NOT NULL, -- 修改时间
  status CHARACTER(1) -- 科研成果状态(0-删除，1-发布)
);
CREATE UNIQUE INDEX research_result_id_uindex ON research_result USING BTREE (id);
COMMENT ON TABLE public.research_result IS '科研成果';
COMMENT ON COLUMN public.research_result.name IS '成果名称';
COMMENT ON COLUMN public.research_result.level IS '技术水平';
COMMENT ON COLUMN public.research_result.org_name IS '所属机构';
COMMENT ON COLUMN public.research_result.department IS '所属部门';
COMMENT ON COLUMN public.research_result.subject IS '行业领域';
COMMENT ON COLUMN public.research_result.industry IS '应用领域';
COMMENT ON COLUMN public.research_result.descp IS '成果简介';
COMMENT ON COLUMN public.research_result.apply_descp IS '应用介绍';
COMMENT ON COLUMN public.research_result.prospect IS '产业化前景';
COMMENT ON COLUMN public.research_result.indicator IS '技术指标';
COMMENT ON COLUMN public.research_result.advantage IS '技术优势';
COMMENT ON COLUMN public.research_result.benefit IS '经济和社会效益';
COMMENT ON COLUMN public.research_result.cooperation IS '合作备注';
COMMENT ON COLUMN public.research_result.linkman IS '联系人';
COMMENT ON COLUMN public.research_result.addr IS '地址';
COMMENT ON COLUMN public.research_result.zip_code IS '邮编';
COMMENT ON COLUMN public.research_result.tel IS '办公电话';
COMMENT ON COLUMN public.research_result.mobile IS '手机';
COMMENT ON COLUMN public.research_result.email IS '邮箱';
COMMENT ON COLUMN public.research_result.pic IS '图片';
COMMENT ON COLUMN public.research_result.create_time IS '创建时间';
COMMENT ON COLUMN public.research_result.modify_time IS '修改时间';
COMMENT ON COLUMN public.research_result.status IS '科研成果状态(0-删除，1-发布)';

-- ------------------------------------
-- Table structure for public.researcher
-- ------------------------------------
CREATE TABLE public.researcher (
  id CHARACTER(32) NOT NULL, -- 研究成果ID
  professor_id CHARACTER(32) NOT NULL DEFAULT '################################'::bpchar, -- 研究者ID
  name TEXT NOT NULL, -- 研究者姓名
  PRIMARY KEY (id, name)
);
CREATE UNIQUE INDEX researchers_key ON researcher USING BTREE (id, name);
COMMENT ON COLUMN public.researcher.id IS '研究成果ID';
COMMENT ON COLUMN public.researcher.professor_id IS '研究者ID';
COMMENT ON COLUMN public.researcher.name IS '研究者姓名';

-- ------------------------------------
-- Table structure for res_result_key_word
-- ------------------------------------
CREATE TABLE public.res_result_key_word (
  id CHARACTER(32) NOT NULL, -- 科研成果ID
  kw TEXT NOT NULL -- 关键词
);
COMMENT ON TABLE public.res_result_key_word IS '科研成果关键词';
COMMENT ON COLUMN public.res_result_key_word.id IS '科研成果ID';
COMMENT ON COLUMN public.res_result_key_word.kw IS '关键词';
